function [F, rts, iter, res] = ClosestPolyComp(sys,support,tcond,init, maxiter) 
%function [F, roots, iter] = ClosestPolyComp(sys,support,numpts, tcond,init, maxiter) 
%
% F is a cell representing a system close to sys but having the 
%   desired roots and multiplicities
% 
% rts is a NxM matrix containing the common roots of F
% 
% iter is the number of iterations needed (<=maxiter)
% 
% sys is a cell representing multivariate polynomials
% 
% support is a cell containing support polynomials
% 
% tcond is a cell of cells containing t conds for each point
% 
% init is a NxM matrix representint initial iterate
% 
% maxiter is the maximum number of iterations allowed (default 100)

nsup = size(support,2)/2;
npoly = size(sys, 2)/2;
[npts, nvar] = size(init);
for i = 1:npts
    ntc(i) = size(tcond{i}, 2)/2;
end
totalcond = sum(ntc);

if (nsup > totalcond)
    [F, rts, iter] = ClosestPolyArbSupComp(sys, support, tcond, init, maxiter);
    return;
end

rts = init;
vrts = ctov(rts.').';
iter = 0;
minstep = 10^(-12);
stepsize = minstep+1;
I = eye(nvar);
minres = 10^(-8);
newres = minres + 1;
sk = 0;
maxsk = 15;
%while (iter < maxiter && stepsize > minstep)
while (iter < maxiter && sk < maxsk)    
    [fev, df] = buildfev(rts, sys, tcond);

    V = VandMat(rts, nsup, ntc, support, tcond);
    dV = {};
    for i = 1:nvar
        dsup = support;
        for j = 1:nsup
            [dsup{2*j-1}, dsup{2*j}] = mpolydiff(support{2*j-1}, support{2*j}, [1], I(i,:));
        end
        dV{i} = VandMat(rts, nsup, ntc, dsup, tcond);
    end
    VC = V;
    V = ctom(V);
    
    fev = ctov(fev);
    F = V\fev;
    FC = vtoc(F);
    allF = F(:);
    allfev = fev(:);
    
    J = zeros(npoly*totalcond*2, npts*nvar*2);
    
    col = 1;
    for j = 1:npts
        for k = 1:nvar
            ddV = zeros(totalcond, nsup);
            ddV((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),:) = dV{k}((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),:);

            ddf = zeros(totalcond, npoly);
            for i = 1:npoly
                ddf((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),i) = df{i}((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),k);
            end
            %ddf = ctov(ddf);
            %ddV = ctom(ddV);
            
            tmp = VC\(ddf - ddV*FC);
            tmp = ctom(tmp);
            rtmp = tmp(:, 1:2:end);
            ctmp = tmp(:, 2:2:end);
            J(: ,col) = rtmp(:);
            J(: ,col+1) = ctmp(:);
            col = col + 2;
        end
    end

    step = -J\allF;
%line search
    currentres = norm(fev(:));
    
    
    newrts = vrts;
    for i = 1:npts
        newrts(i,:) = newrts(i,:) + step(((i-1)*2*nvar+1):i*2*nvar,1).';
    end
    [newfev] = buildfev(vtoc(newrts.').', sys, tcond);
    newfev = ctov(newfev);
    newres = norm(newfev(:));
    sk = 0;
    
    while newres + eps > currentres && sk < maxsk+1
        step = 0.5 .* step;
        newrts = vrts;
        for i = 1:npts
            newrts(i,:) = newrts(i,:) + step(((i-1)*2*nvar+1):i*2*nvar,1).';
        end
        [newfev] = buildfev(vtoc(newrts.').', sys, tcond);
        newfev = ctov(newfev);
        newres = norm(newfev(:));
        sk = sk+1;
    end

    step = vtoc(step);
    rts = vtoc(newrts.').';    
    vrts = ctov(rts.').';

    stepsize = norm(step,2);
    iter = iter+1;
end
F = vtoc(F);
rts = vtoc(rts').';
res = newres;    

end
