function [F, rts, iter, res] = ClosestPolySimp(sys,support,tcond,init, maxiter) 
%function [F, roots, iter] = ClosestPoly(sys,support,numpts, tcond,init, maxiter) 
%
% F is a cell representing a system close to sys but having the 
%   desired roots and multiplicities
% 
% rts is a NxM matrix containing the common roots of F
% 
% iter is the number of iterations needed (<=maxiter)
% 
% sys is a cell representing multivariate polynomials
% 
% support is a cell containing support polynomials
% 
% tcond is a cell of cells containing t conds for each point
% 
% init is a NxM matrix representint initial iterate
% 
% maxiter is the maximum number of iterations allowed (default 100)

nsup = size(support,2)/2;
npoly = size(sys, 2)/2;
[npts, nvar] = size(init);
for i = 1:npts
    ntc(i) = size(tcond{i}, 2)/2;
end
totalcond = sum(ntc);

if (nsup > totalcond)
    [F, rts, iter] = ClosestPolyArbSup(sys, support, tcond, init, maxiter);
    return;
end

rts = init;
iter = 0;
minstep = 10^(-12);
stepsize = minstep+1;
I = eye(nvar);
minres = 10^(-8);
newres = minres + 1;
sk = 0;
maxsk = 15;
%while (iter < maxiter && stepsize > minstep)
while (iter < maxiter && sk < maxsk)    
    [fev, df] = buildfev(rts, sys, tcond);

    V = VandMat(rts, nsup, ntc, support, tcond);
    dV = {};
    for i = 1:nvar
        dsup = support;
        for j = 1:nsup
            [dsup{2*j-1}, dsup{2*j}] = mpolydiff(support{2*j-1}, support{2*j}, [1], I(i,:));
        end
        dV{i} = VandMat(rts, nsup, ntc, dsup, tcond);
    end
    
    F = V\fev;
    
    allF = F(:);
    allfev = fev(:);
    
    J = zeros(npoly*totalcond, npts*nvar);
    
    col = 1;
    for j = 1:npts
        for k = 1:nvar
            ddV = zeros(totalcond, nsup);
            ddV((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),:) = dV{k}((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),:);

            ddf = zeros(totalcond, npoly);
            for i = 1:npoly
                ddf((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),i) = df{i}((sum(ntc(1:(j-1)))+1):(sum(ntc(1:j))),k);
            end            
            tmp = (ddf - ddV*F);
            J(: ,col) = tmp(:);
            col = col + 1;
        end
    end

    step = -J\allfev;
%line search
    currentres = norm(fev(:));
    
    
    newrts = rts;
    for i = 1:npts
        newrts(i,:) = newrts(i,:) + step(((i-1)*nvar+1):i*nvar,1).';
    end
    [newfev] = buildfev(newrts, sys, tcond);
    newres = norm(newfev(:));
    sk = 0;
    
%    while newres + eps > currentres && sk < maxsk+1
    while newres > 0.99 * currentres && sk < maxsk+1

        step = 0.5 .* step;
        newrts = rts;
        for i = 1:npts
            newrts(i,:) = newrts(i,:) + step(((i-1)*nvar+1):i*nvar,1).';
        end
%        newrts(:) = newrts(:) + step;
        [newfev] = buildfev(newrts, sys, tcond);
        newres = norm(newfev(:));
        sk = sk+1;
    end
%%
    if sk == 0
        dbls = 0;
      %see if we can double the step size
      while newres < 0.99 * currentres && dbls < 10
          newrts = rts;
          for i = 1:npts
              newrts(i,:) = newrts(i,:) + 2.0 .* step(((i-1)*nvar+1):i*nvar,1).';
          end
          [newfev] = buildfev(newrts, sys, tcond);
          currentres = newres;
          newres = norm(newfev(:));
          if newres < 0.99 * currentres
              step = 2.0 .* step;
          end
          dbls = dbls + 1;
      end
      newres = currentres; %corrects for return value
    end    
%%  

    for i = 1:npts
        rts(i,:) = rts(i,:) + step(((i-1)*nvar+1):i*nvar,1).';
    end
    stepsize = norm(step,2);
    iter = iter+1;
end

        
res = newres;    

end
