function V=VandMat(pts, numsupport, numcond, varargin)
%function V=VandMat(pts, numsupport, numcond)
%
%  Builds a generalized Vandermonde matrix
%
% pts - an (NxM) the coordinates of the points used to build
%  the matrix, each row corresponds to a point
%
% numsupport - number of support functions
% numcond - An N length vector containing the number of conditions
%  to be satisfied at each point
%
% varargin - must be a list of multivariate coeff/support pairs
%  The first numsupport pairs must be the polynomial support
%  for the vandermonde matrix
%
%  can also be a single cell
%  or two cells, the first containing the support and the
%  second containing the tangential conditions
%
%  The next sum(numcond) pairs represent the differential
%  operators that vanish at the desired point

if nargin == 4
    support = varargin{1}(1:2*numsupport);
    tcond = varargin{1}((2*numsupport+1):(2*numsupport+2*sum(numcond)));
elseif nargin == 5
    support = varargin{1};
    tcond = varargin{2};
elseif nargin == (3 + 2*numsupport + 2*sum(numcond))
    support = varargin(1:2*numsupport);
    tcond = varargin((2*numsupport+1):(2*numsupport+2*sum(numcond)));
else
    ERROR('Not Enough Args\n', '%s', 'Too Few Args');
end

%the ith support element:
%  coeff:   varargin{-1+2*i}
%  support: varargin{2*i}
%
%the ith tangential cond for the jth point
%  coeff:   varargin{-1 + 2*numsupport + 2*sum(numcond(1:j-1)) + 2*i}
%  support: varargin{ 2*numsupport + 2*sum(numcond(1:j-1)) + 2*i}

ncol = numsupport;
nrow = sum(numcond);
npts = size(pts, 1);
V = zeros(nrow, ncol);
for col = 1:ncol
    row = 1;
    for j = 1:npts
        for k = 1:numcond(j)
            poly = support{-1+2*col};
            sup = support{2*col};
            
            dp = tcond{j}{2*k-1};
            ds = tcond{j}{2*k};
            pt = pts(j,:);
            [p, s] = mpolydiff(poly, sup, dp, ds);
            V(row, col) = mpolyeval(p, s, pt);
            row = row + 1;
        end
    end
end