function [p, s] = mpolydiff(poly, sup, dp, ds)
%function [p, s] = mpolydiff(poly, sup, dp, ds)
%
%poly, sup is a multivariate polynomial coeff/support
%   pair
%
%dp, ds is the polynomial representation of a differential
% operator
% dy/dx1 would be [1] [1 0]
% 0.5 + 0.2dy/dx1 + 0.4d^2y/dx2dx1 
%   would be [0.5 0.2 0.4] [0 0;1 0;1 1]
%
%[p, s] is the multivariate polynomial resulting from
%  applying [dp, ds] to [poly, sup]

[PN, PM] = size(sup);
[DN, DM] = size(ds);
%make sure the support matrices are the same size
if PM<DM
    tds = ds;
    tsup = zeros(PN, DM);
    tsup(:, 1:PM) = sup;
elseif DM < PM
    tsup = sup;
    tds = zeros(DN, PM);
    tds(:, 1:DM) = ds;
else
    tsup = sup;
    tds = ds;
end
    
p = [];
s = [];

for i=1:DN
    for j=1:PN
        if tds(i, :) <= tsup(j,:)  %check to see if derivative is trivially 0
            termp = poly(j)*dp(i);  %calculate coeff
            termsup = tsup(j, :);     %start with current monomial
            drow = tds(i,:);
            done = 0;
            while ~done
                if drow == 0 %there are no more derivatives to take
                    done = 1;   %we are done
                else
                    k = 1;
                    %find the next derivative to take
                    while drow(k) <= 0
                        k = k+1;
                    end
                    %take the derivative
                    termp = termp * termsup(k);
                    termsup(k) = termsup(k) - 1;
                    drow(k) = drow(k) - 1;
                end
            end
            [p, s] = mpolyadd(p, s, termp, termsup);
        else
            continue
        end
    end
end