function val = mpolyeval(poly, support, x)
%mpolyeval.m by Scott Pope

%val = mpolyeval(poly, support, x)
%Computes the value of a multivariate polynomial
%
%poly is a a vector of 
%  length N and represents the coefficients
%  of the multivariate polynomial with the given support
%
%Support is a NxM matrix.  Each row corresponds to the
%  coefficients of a support element
%
%x is a vector of length N and represents the
%  values to evaluate the polynomial.

[N,M] = size(support);
if (N == 0 | M == 0)
    val = 0;
    return
end

sval = zeros(size(poly));

for i=1:N
  sval(i) = 1;
  for j=1:M
    sval(i) = sval(i)*x(j)^support(i,j);
  end
end
val = poly*sval.';
