function [p, s] = mpolysimplify(poly, support)
%function [p,s] = mpolysimplify(poly, support)
%
%Support is an NxM matrix of exponents
%
%poly is a vector of N elements representing coefficients
%  of a multivariate polynomial with given support
%
%[p, s] represents the same polynomial in lexigraphical
%  order and with duplicate monomials combined
%
% ex. [p,s] = mpolysimplify([2 3 7], [2 4;2 4; 1 0])
%  yields
%  p = [7 5]
%  s = [1 0;2 4]

[pt, st] = lexorder(poly, support);

[N, M] = size(st);
if ~N
    p = [];
    s = [];
    return
end

i = 1; j=1;
index = [1];

while i+j<=N,
    
    if st(i,:)==st(i+j,:)
        pt(i) = pt(i)+pt(i+j);
        
        j = j+1;
    else
        i = i+j;
        j = 1;
        index = [index i];
    end
end
p = pt(index);
s = st(index,:);

 